//------------------------------------------------------------------------------
//
//   Greg's Blocks - Generic inventory implementation
//
//------------------------------------------------------------------------------

package gcewing.blocks;

import net.minecraft.inventory.*;
import net.minecraft.item.*;
import net.minecraft.nbt.*;

class Inventory extends InventoryBasic {

	IInventory parent;

	public Inventory(String name, int numSlots, IInventory parent) {
		super(name, numSlots);
		this.parent = parent;
	}

  public void onInventoryChanged() {
		if (parent != null)
			parent.onInventoryChanged();
	}

	public void readFromNBT(NBTTagCompound tc) {
		NBTTagList tlist = tc.getTagList(getInvName());
		int n = this.getSizeInventory();
		for (int i = 0; i < n; i++)
			setInventorySlotContents(i, null);
		for (int i = 0; i < tlist.tagCount(); i++) {
			NBTTagCompound titem = (NBTTagCompound)tlist.tagAt(i);
			byte s = titem.getByte("Slot");
			if (s >= 0 && s < n)
				setInventorySlotContents(s, ItemStack.loadItemStackFromNBT(titem));
		}
	}

	public void writeToNBT(NBTTagCompound tc) {
		NBTTagList tlist = new NBTTagList();
		for (int i = 0; i < getSizeInventory(); i++) {
			ItemStack stack = getStackInSlot(i);
			if (stack != null) {
				NBTTagCompound titem = new NBTTagCompound();
				titem.setByte("Slot", (byte)i);
				stack.writeToNBT(titem);
				tlist.appendTag(titem);
			}
		}
		tc.setTag(getInvName(), tlist);
	}

}
